# outline-vpn-api

A Python API wrapper for [Outline VPN](https://getoutline.org/)

[![Pylint](https://github.com/jadolg/outline-vpn-api/actions/workflows/pylint.yml/badge.svg)](https://github.com/jadolg/outline-vpn-api/actions/workflows/pylint.yml) 
[![Test](https://github.com/jadolg/outline-vpn-api/actions/workflows/test.yml/badge.svg)](https://github.com/jadolg/outline-vpn-api/actions/workflows/test.yml)
